Exception: BasicSettings::FieldError

Inherits:
StandardError
  • Object
show all
Defined in:
lib/basic_settings.rb

Overview

Error raised when a value does not match the type constraint.

Instance Attribute Summary collapse

Instance Attribute Details

#field_nameSymbol (readonly)

The field that rejected the value

Returns:

  • (Symbol)


344
345
346
# File 'lib/basic_settings.rb', line 344

def field_name
  @field_name
end

#settings_classClass (readonly)

The settings class that rejected the value

Returns:

  • (Class)


338
339
340
# File 'lib/basic_settings.rb', line 338

def settings_class
  @settings_class
end

#type_descriptionString? (readonly)

A description of the type constraint, or nil if the field didn't exist.

Returns:

  • (String, nil)


350
351
352
# File 'lib/basic_settings.rb', line 350

def type_description
  @type_description
end

#valueObject (readonly)

The value that did not match

Returns:

  • (Object)


332
333
334
# File 'lib/basic_settings.rb', line 332

def value
  @value
end